==> net.bluemind.p2.platform-5.4.2696.zip: store/types/getters.ts <==
// root
export const ACTIVE_MESSAGE = "ACTIVE_MESSAGE";
export const ALL_CONVERSATIONS_ARE_SELECTED = "ALL_CONVERSATIONS_ARE_SELECTED";
export const ALL_SELECTED_CONVERSATIONS_ARE_FLAGGED = "ALL_SELECTED_CONVERSATIONS_ARE_FLAGGED";
export const ALL_SELECTED_CONVERSATIONS_ARE_READ = "ALL_SELECTED_CONVERSATIONS_ARE_READ";
export const ALL_SELECTED_CONVERSATIONS_ARE_UNFLAGGED = "ALL_SELECTED_CONVERSATIONS_ARE_UNFLAGGED";
export const ALL_SELECTED_CONVERSATIONS_ARE_UNREAD = "ALL_SELECTED_CONVERSATIONS_ARE_UNREAD";
export const ALL_SELECTED_CONVERSATIONS_ARE_WRITABLE = "ALL_SELECTED_CONVERSATIONS_ARE_WRITABLE";
export const CONVERSATIONS_ACTIVATED = "CONVERSATIONS_ACTIVATED";
export const CURRENT_MAILBOX = "CURRENT_MAILBOX";
export const FILTERED_GROUP_MAILBOX_RESULTS = "FILTERED_GROUP_MAILBOX_RESULTS";
export const FILTERED_MAILSHARE_RESULTS = "FILTERED_MAILSHARE_RESULTS";
export const FILTERED_USER_RESULTS = "FILTERED_USER_RESULTS";
export const FOLDER_LIST_IS_EMPTY = "FOLDER_LIST_IS_EMPTY";
export const GROUP_MAILBOX_FOLDERS = "GROUP_MAILBOX_FOLDERS";
export const GROUP_MAILBOX_ROOT_FOLDERS = "GROUP_MAILBOX_ROOT_FOLDERS";
export const IS_ACTIVE_MESSAGE = "IS_ACTIVE_MESSAGE";
export const IS_CURRENT_CONVERSATION = "IS_CURRENT_CONVERSATION";
export const MAILBOX_FOLDERS = "MAILBOX_FOLDERS";
export const MAILBOX_DEFAULT_FOLDER = "MAILBOX_DEFAULT_FOLDER";
export const MAILBOX_ROOT_FOLDERS = "MAILBOX_ROOT_FOLDERS";
export const MAILBOX_INBOX = "MAILBOX_INBOX";
export const MAILBOX_JUNK = "MAILBOX_JUNK";
export const MAILBOX_SENT = "MAILBOX_SENT";
export const MAILBOX_TRASH = "MAILBOX_TRASH";
export const MAILSHARE_FOLDERS = "MAILSHARE_FOLDERS";
export const MAILSHARE_ROOT_FOLDERS = "MAILSHARE_ROOT_FOLDERS";
export const MY_DRAFTS = "MY_DRAFTS";
export const MY_INBOX = "MY_INBOX";
export const MY_JUNK = "MY_JUNK";
export const MY_MAILBOX_FOLDERS = "MY_MAILBOX_FOLDERS";
export const MY_MAILBOX_IS_READY = "MY_MAILBOX_IS_READY";
export const MY_MAILBOX_ROOT_FOLDERS = "MY_MAILBOX_ROOT_FOLDERS";
export const MY_OUTBOX = "MY_OUTBOX";
export const MY_SENT = "MY_SENT";
export const MY_TEMPLATES = "MY_TEMPLATES";
export const MY_TRASH = "MY_TRASH";
export const NEXT_CONVERSATION = "NEXT_CONVERSATION";
export const SELECTION = "SELECTION";
export const SELECTION_FLAGS = "SELECTION_FLAGS";
export const ADDRESS_AUTOCOMPLETE = "ADDRESS_AUTOCOMPLETE";

// mailboxes
export const GROUP_MAILBOXES = "GROUP_MAILBOXES";
export const GROUP_MAILBOX_KEYS = "GROUP_MAILBOX_KEYS";
export const MAILBOX_BY_NAME = "MAILBOX_BY_NAME";
export const MAILBOXES = "MAILBOXES";
export const MAILBOXES_ARE_LOADED = "MAILBOXES_ARE_LOADED";
export const MAILSHARE_KEYS = "MAILSHARE_KEYS";
export const MAILSHARES = "MAILSHARES";
export const MY_MAILBOX = "MY_MAILBOX";
export const MY_MAILBOX_KEY = "MY_MAILBOX_KEY";
export const USER_MAILBOXES = "USER_MAILBOXES";

// folders
export const FOLDER_BY_PATH = "FOLDER_BY_PATH";
export const FOLDER_GET_CHILDREN = "FOLDER_GET_CHILDREN";
export const FOLDER_GET_DESCENDANTS = "FOLDER_GET_DESCENDANTS";
export const FOLDER_HAS_CHILDREN = "FOLDER_HAS_CHILDREN";
export const FOLDERS = "FOLDERS";
export const FOLDERS_BY_PATH = "FOLDERS_BY_PATH";
export const IS_DESCENDANT = "IS_DESCENDANT";

// messages
export const MESSAGE_IS_LOADED = "MESSAGE_IS_LOADED";
export const MESSAGE_IS_LOADING = "MESSAGE_IS_LOADING";

// selection
export const SELECTION_IS_EMPTY = "SELECTION_IS_EMPTY";
export const ONE_CONVERSATION_SELECTED = "ONE_CONVERSATION_SELECTED";
export const SEVERAL_CONVERSATIONS_SELECTED = "SEVERAL_CONVERSATIONS_SELECTED";
export const CONVERSATION_IS_SELECTED = "CONVERSATION_IS_SELECTED";
export const SELECTION_KEYS = "SELECTION_KEYS";

// conversationList
export const CONVERSATION_LIST_ALL_KEYS = "CONVERSATION_LIST_ALL_KEYS";
export const CONVERSATION_LIST_COUNT = "CONVERSATION_LIST_COUNT";
export const CONVERSATION_LIST_DELETED_FILTER_ENABLED = "CONVERSATION_LIST_DELETED_FILTER_ENABLED";
export const CONVERSATION_LIST_FILTERED = "CONVERSATION_LIST_FILTERED";
export const CONVERSATION_LIST_FLAGGED_FILTER_ENABLED = "CONVERSATION_LIST_FLAGGED_FILTER_ENABLED";
export const CONVERSATION_LIST_HAS_NEXT = "CONVERSATION_LIST_HAS_NEXT";
export const CONVERSATION_LIST_IS_LOADING = "CONVERSATION_LIST_IS_LOADING";
export const CONVERSATION_LIST_IS_REJECTED = "CONVERSATION_LIST_IS_REJECTED";
export const CONVERSATION_LIST_IS_RESOLVED = "CONVERSATION_LIST_IS_RESOLVED";
export const CONVERSATION_LIST_KEYS = "CONVERSATION_LIST_KEYS";
export const CONVERSATION_LIST_TOTAL_PAGES = "CONVERSATION_LIST_TOTAL_PAGES";
export const CONVERSATION_LIST_UNREAD_FILTER_ENABLED = "CONVERSATION_LIST_UNREAD_FILTER_ENABLED";

// search
export const IS_SEARCH_ENABLED = "IS_SEARCH_ENABLED";
export const HAS_PATTERN = "HAS_PATTERN";
export const IS_TYPING_IN_SEARCH = "IS_TYPING_IN_SEARCH";

// conversations
export const CONVERSATION_IS_LOADED = "CONVERSATION_IS_LOADED";
export const CONVERSATION_MESSAGE_BY_KEY = "CONVERSATION_MESSAGE_BY_KEY";
export const CONVERSATION_METADATA = "CONVERSATION_METADATA";
export const CURRENT_CONVERSATION_METADATA = "CURRENT_CONVERSATION_METADATA";

// folderList
export const FOLDER_LIST_IS_FILTERED = "FOLDER_LIST_IS_FILTERED";
export const FOLDER_LIST_IS_LOADING = "FOLDER_LIST_IS_LOADING";
export const FOLDER_LIST_LIMIT_FOR_GROUP_MAILBOX = "FOLDER_LIST_LIMIT_FOR_GROUP_MAILBOX";
export const FOLDER_LIST_LIMIT_FOR_MAILSHARE = "FOLDER_LIST_LIMIT_FOR_MAILSHARE";
export const FOLDER_LIST_LIMIT_FOR_USER = "FOLDER_LIST_LIMIT_FOR_USER";

// messageCompose
export const MAILTIPS_ALERTS = "MAILTIPS_ALERTS";
export const IS_REPLY_TO_SHOWN = "IS_REPLY_TO_SHOWN";
export const IS_SENDER_SHOWN = "IS_SENDER_SHOWN";
export const GET_DRAFT_CONTENT = "GET_DRAFT_CONTENT";
export const SIGNATURE = "SIGNATURE";
export const DISCLAIMER = "DISCLAIMER";

==> net.bluemind.p2.platform-5.5.3112.zip: store/types/getters.ts <==
// root
export const ACTIVE_MESSAGE = "ACTIVE_MESSAGE";
export const ALL_CONVERSATIONS_ARE_SELECTED = "ALL_CONVERSATIONS_ARE_SELECTED";
export const ALL_SELECTED_CONVERSATIONS_ARE_FLAGGED = "ALL_SELECTED_CONVERSATIONS_ARE_FLAGGED";
export const ALL_SELECTED_CONVERSATIONS_ARE_READ = "ALL_SELECTED_CONVERSATIONS_ARE_READ";
export const ALL_SELECTED_CONVERSATIONS_ARE_UNFLAGGED = "ALL_SELECTED_CONVERSATIONS_ARE_UNFLAGGED";
export const ALL_SELECTED_CONVERSATIONS_ARE_UNREAD = "ALL_SELECTED_CONVERSATIONS_ARE_UNREAD";
export const ALL_SELECTED_CONVERSATIONS_ARE_WRITABLE = "ALL_SELECTED_CONVERSATIONS_ARE_WRITABLE";
export const CONVERSATIONS_ACTIVATED = "CONVERSATIONS_ACTIVATED";
export const CURRENT_MAILBOX = "CURRENT_MAILBOX";
export const FILTERED_GROUP_MAILBOX_RESULTS = "FILTERED_GROUP_MAILBOX_RESULTS";
export const FILTERED_MAILSHARE_RESULTS = "FILTERED_MAILSHARE_RESULTS";
export const FILTERED_USER_RESULTS = "FILTERED_USER_RESULTS";
export const FOLDER_LIST_IS_EMPTY = "FOLDER_LIST_IS_EMPTY";
export const GROUP_MAILBOX_FOLDERS = "GROUP_MAILBOX_FOLDERS";
export const GROUP_MAILBOX_ROOT_FOLDERS = "GROUP_MAILBOX_ROOT_FOLDERS";
export const IS_ACTIVE_MESSAGE = "IS_ACTIVE_MESSAGE";
export const IS_CURRENT_CONVERSATION = "IS_CURRENT_CONVERSATION";
export const MAILBOX_FOLDERS = "MAILBOX_FOLDERS";
export const MAILBOX_DEFAULT_FOLDER = "MAILBOX_DEFAULT_FOLDER";
export const MAILBOX_ROOT_FOLDERS = "MAILBOX_ROOT_FOLDERS";
export const MAILBOX_INBOX = "MAILBOX_INBOX";
export const MAILBOX_JUNK = "MAILBOX_JUNK";
export const MAILBOX_SENT = "MAILBOX_SENT";
export const MAILBOX_TRASH = "MAILBOX_TRASH";
export const MAILSHARE_FOLDERS = "MAILSHARE_FOLDERS";
export const MAILSHARE_ROOT_FOLDERS = "MAILSHARE_ROOT_FOLDERS";
export const MY_DRAFTS = "MY_DRAFTS";
export const MY_INBOX = "MY_INBOX";
export const MY_JUNK = "MY_JUNK";
export const MY_MAILBOX_FOLDERS = "MY_MAILBOX_FOLDERS";
export const MY_MAILBOX_IS_READY = "MY_MAILBOX_IS_READY";
export const MY_MAILBOX_ROOT_FOLDERS = "MY_MAILBOX_ROOT_FOLDERS";
export const MY_OUTBOX = "MY_OUTBOX";
export const MY_SENT = "MY_SENT";
export const MY_TEMPLATES = "MY_TEMPLATES";
export const MY_TRASH = "MY_TRASH";
export const NEXT_CONVERSATION = "NEXT_CONVERSATION";
export const SELECTION = "SELECTION";
export const SELECTION_FLAGS = "SELECTION_FLAGS";
export const ADDRESS_AUTOCOMPLETE = "ADDRESS_AUTOCOMPLETE";

// mailboxes
export const GROUP_MAILBOXES = "GROUP_MAILBOXES";
export const GROUP_MAILBOX_KEYS = "GROUP_MAILBOX_KEYS";
export const MAILBOX_BY_NAME = "MAILBOX_BY_NAME";
export const MAILBOXES = "MAILBOXES";
export const MAILBOXES_ARE_LOADED = "MAILBOXES_ARE_LOADED";
export const MAILSHARE_KEYS = "MAILSHARE_KEYS";
export const MAILSHARES = "MAILSHARES";
export const MY_MAILBOX = "MY_MAILBOX";
export const MY_MAILBOX_KEY = "MY_MAILBOX_KEY";
export const USER_MAILBOXES = "USER_MAILBOXES";

// folders
export const FOLDER_BY_PATH = "FOLDER_BY_PATH";
export const FOLDER_GET_CHILDREN = "FOLDER_GET_CHILDREN";
export const FOLDER_GET_DESCENDANTS = "FOLDER_GET_DESCENDANTS";
export const FOLDER_HAS_CHILDREN = "FOLDER_HAS_CHILDREN";
export const FOLDERS = "FOLDERS";
export const FOLDERS_BY_PATH = "FOLDERS_BY_PATH";
export const IS_DESCENDANT = "IS_DESCENDANT";

// messages
export const MESSAGE_IS_LOADED = "MESSAGE_IS_LOADED";
export const MESSAGE_IS_LOADING = "MESSAGE_IS_LOADING";

// selection
export const SELECTION_IS_EMPTY = "SELECTION_IS_EMPTY";
export const ONE_CONVERSATION_SELECTED = "ONE_CONVERSATION_SELECTED";
export const SEVERAL_CONVERSATIONS_SELECTED = "SEVERAL_CONVERSATIONS_SELECTED";
export const CONVERSATION_IS_SELECTED = "CONVERSATION_IS_SELECTED";
export const SELECTION_KEYS = "SELECTION_KEYS";

// conversationList
export const CONVERSATION_LIST_ALL_KEYS = "CONVERSATION_LIST_ALL_KEYS";
export const CONVERSATION_LIST_COUNT = "CONVERSATION_LIST_COUNT";
export const CONVERSATION_LIST_DELETED_FILTER_ENABLED = "CONVERSATION_LIST_DELETED_FILTER_ENABLED";
export const CONVERSATION_LIST_FILTERED = "CONVERSATION_LIST_FILTERED";
export const CONVERSATION_LIST_FLAGGED_FILTER_ENABLED = "CONVERSATION_LIST_FLAGGED_FILTER_ENABLED";
export const CONVERSATION_LIST_HAS_NEXT = "CONVERSATION_LIST_HAS_NEXT";
export const CONVERSATION_LIST_IS_LOADING = "CONVERSATION_LIST_IS_LOADING";
export const CONVERSATION_LIST_IS_REJECTED = "CONVERSATION_LIST_IS_REJECTED";
export const CONVERSATION_LIST_IS_RESOLVED = "CONVERSATION_LIST_IS_RESOLVED";
export const CONVERSATION_LIST_KEYS = "CONVERSATION_LIST_KEYS";
export const CONVERSATION_LIST_TOTAL_PAGES = "CONVERSATION_LIST_TOTAL_PAGES";
export const CONVERSATION_LIST_UNREAD_FILTER_ENABLED = "CONVERSATION_LIST_UNREAD_FILTER_ENABLED";

// search
export const IS_SEARCH_ENABLED = "IS_SEARCH_ENABLED";
export const HAS_PATTERN = "HAS_PATTERN";
export const IS_TYPING_IN_SEARCH = "IS_TYPING_IN_SEARCH";

// conversations
export const CONVERSATION_IS_LOADED = "CONVERSATION_IS_LOADED";
export const CONVERSATION_MESSAGE_BY_KEY = "CONVERSATION_MESSAGE_BY_KEY";
export const CONVERSATION_METADATA = "CONVERSATION_METADATA";
export const CURRENT_CONVERSATION_METADATA = "CURRENT_CONVERSATION_METADATA";

// folderList
export const FOLDER_LIST_IS_FILTERED = "FOLDER_LIST_IS_FILTERED";
export const FOLDER_LIST_IS_LOADING = "FOLDER_LIST_IS_LOADING";
export const FOLDER_LIST_LIMIT_FOR_GROUP_MAILBOX = "FOLDER_LIST_LIMIT_FOR_GROUP_MAILBOX";
export const FOLDER_LIST_LIMIT_FOR_MAILSHARE = "FOLDER_LIST_LIMIT_FOR_MAILSHARE";
export const FOLDER_LIST_LIMIT_FOR_USER = "FOLDER_LIST_LIMIT_FOR_USER";

// messageCompose
export const MAILTIPS_ALERTS = "MAILTIPS_ALERTS";
export const MAILTIPS_OOF = "MAILTIPS_OOF";
export const MAILTIPS_OVER_QUOTA = "MAILTIPS_OVER_QUOTA";
export const IS_REPLY_TO_SHOWN = "IS_REPLY_TO_SHOWN";
export const IS_SENDER_SHOWN = "IS_SENDER_SHOWN";
export const GET_DRAFT_CONTENT = "GET_DRAFT_CONTENT";
export const SIGNATURE = "SIGNATURE";
export const DISCLAIMER = "DISCLAIMER";
